# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/explore/explore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.post import post_pb2 as services_dot_post_dot_post__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/explore/explore.proto\x12\x0esocial.explore\x1a\x1cservices/common/common.proto\x1a\x18services/post/post.proto\"#\n\x10GeoSearchRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"G\n\x07\x41\x64\x64ress\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lon\x18\x04 \x01(\x01\";\n\x11GeoSearchResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.explore.Address2\xda\x01\n\x0e\x45xploreService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12\x43\n\x07GetFeed\x12\x19.social.common.Pagination\x1a\x1d.social.post.PostListResponse\x12P\n\tGeoSearch\x12 .social.explore.GeoSearchRequest\x1a!.social.explore.GeoSearchResponseb\x06proto3')



_GEOSEARCHREQUEST = DESCRIPTOR.message_types_by_name['GeoSearchRequest']
_ADDRESS = DESCRIPTOR.message_types_by_name['Address']
_GEOSEARCHRESPONSE = DESCRIPTOR.message_types_by_name['GeoSearchResponse']
GeoSearchRequest = _reflection.GeneratedProtocolMessageType('GeoSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _GEOSEARCHREQUEST,
  '__module__' : 'services.explore.explore_pb2'
  # @@protoc_insertion_point(class_scope:social.explore.GeoSearchRequest)
  })
_sym_db.RegisterMessage(GeoSearchRequest)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'services.explore.explore_pb2'
  # @@protoc_insertion_point(class_scope:social.explore.Address)
  })
_sym_db.RegisterMessage(Address)

GeoSearchResponse = _reflection.GeneratedProtocolMessageType('GeoSearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _GEOSEARCHRESPONSE,
  '__module__' : 'services.explore.explore_pb2'
  # @@protoc_insertion_point(class_scope:social.explore.GeoSearchResponse)
  })
_sym_db.RegisterMessage(GeoSearchResponse)

_EXPLORESERVICE = DESCRIPTOR.services_by_name['ExploreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GEOSEARCHREQUEST._serialized_start=106
  _GEOSEARCHREQUEST._serialized_end=141
  _ADDRESS._serialized_start=143
  _ADDRESS._serialized_end=214
  _GEOSEARCHRESPONSE._serialized_start=216
  _GEOSEARCHRESPONSE._serialized_end=275
  _EXPLORESERVICE._serialized_start=278
  _EXPLORESERVICE._serialized_end=496
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/shop/shop.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.product import product_pb2 as services_dot_product_dot_product__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18services/shop/shop.proto\x12\x0bsocial.shop\x1a\x1cservices/common/common.proto\x1a\x1eservices/product/product.proto\x1a\x1eservices/account/account.proto\")\n\x19VerifyDeliveryCodeRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"i\n\x17\x43\x61rtProductSellerStatus\x12(\n\x06status\x18\x01 \x01(\x0e\x32\x18.social.shop.OrderStatus\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\"\xb6\x01\n\x18GetOrdersByStatusRequest\x12-\n\x06status\x18\x01 \x01(\x0e\x32\x18.social.shop.OrderStatusH\x00\x88\x01\x01\x12\x35\n\x07payment\x18\x02 \x01(\x0e\x32\x1f.social.shop.OrderPaymentStatusH\x01\x88\x01\x01\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\x42\t\n\x07_statusB\n\n\x08_payment\"z\n\x15SetOrderStatusRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12(\n\x06status\x18\x02 \x01(\x0e\x32\x18.social.shop.OrderStatus\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\"\x91\x01\n\x17SetProductStatusRequest\x12(\n\x07product\x18\x01 \x01(\x0b\x32\x17.social.product.Product\x12\x10\n\x08order_id\x18\x02 \x01(\t\x12(\n\x06status\x18\x03 \x01(\x0e\x32\x18.social.shop.OrderStatus\x12\x10\n\x08quantity\x18\x04 \x01(\x05\"t\n\x0c\x42ulkProducts\x12(\n\x07product\x18\x01 \x01(\x0b\x32\x17.social.product.Product\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12(\n\x06status\x18\x03 \x01(\x0e\x32\x18.social.shop.OrderStatus\"\\\n\x1b\x42ulkSetProductStatusRequest\x12+\n\x08products\x18\x01 \x03(\x0b\x32\x19.social.shop.BulkProducts\x12\x10\n\x08order_id\x18\x02 \x01(\t\"B\n\x16InventoryInCartRequest\x12(\n\x07product\x18\x01 \x01(\x0b\x32\x17.social.product.Product\"7\n\x0fInventoryInCart\x12\x12\n\nprop_value\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x05\"B\n\x13InventoryInCartList\x12+\n\x05items\x18\x01 \x03(\x0b\x32\x1c.social.shop.InventoryInCart\"d\n\rUpsertRequest\x12(\n\x07product\x18\x01 \x01(\x0b\x32\x17.social.product.Product\x12)\n\x05\x63ount\x18\x02 \x01(\x0e\x32\x1a.social.shop.IncrementType\"\xc4\x01\n\x0b\x43\x61rtProduct\x12(\n\x07product\x18\x01 \x01(\x0b\x32\x17.social.product.Product\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12+\n\x05price\x18\x03 \x01(\x0b\x32\x1c.social.product.ProductPrice\x12\x12\n\nupdated_at\x18\x04 \x01(\x01\x12;\n\rseller_status\x18\x05 \x01(\x0b\x32$.social.shop.CartProductSellerStatus\"A\n\x04\x43\x61rt\x12\r\n\x05owner\x18\x01 \x01(\t\x12*\n\x08products\x18\x02 \x03(\x0b\x32\x18.social.shop.CartProduct\"\x94\x01\n\x0f\x43heckoutRequest\x12\x10\n\x08\x64iscount\x18\x01 \x01(\t\x12\x12\n\naddress_id\x18\x02 \x01(\t\x12\'\n\x08\x64\x65livery\x18\x03 \x01(\x0b\x32\x15.social.shop.Delivery\x12\x32\n\x0epayment_method\x18\x04 \x01(\x0e\x32\x1a.social.shop.PaymentMethod\"W\n\x0fPayOrderRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x32\n\x0epayment_method\x18\x02 \x01(\x0e\x32\x1a.social.shop.PaymentMethod\"`\n\x10PayOrderResponse\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x12\n\npayment_id\x18\x02 \x01(\t\x12\x13\n\x0bpayment_url\x18\x03 \x01(\t\x12\x11\n\tis_unpaid\x18\x04 \x01(\x08\"]\n\x10\x43heckoutResponse\x12!\n\x05order\x18\x01 \x01(\x0b\x32\x12.social.shop.Order\x12\x11\n\tis_unpaid\x18\x02 \x01(\x08\x12\x13\n\x0bpayment_url\x18\x03 \x01(\t\"\x9e\x02\n\x07Payment\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04gate\x18\x03 \x01(\t\x12\x32\n\x06status\x18\x04 \x01(\x0e\x32\".social.shop.Payment.PaymentStatus\x12\x11\n\tcard_hash\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61rd_pan\x18\x06 \x01(\t\x12\x0e\n\x06ref_id\x18\x07 \x01(\t\x12\x11\n\tauthority\x18\x08 \x01(\t\x12\x0e\n\x06\x61mount\x18\t \x01(\x02\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\x03\"5\n\rPaymentStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"2\n\x0bPaymentList\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.social.shop.Payment\"\\\n\x08\x44\x65livery\x12\x0e\n\x06method\x18\x01 \x01(\x05\x12\r\n\x05price\x18\x02 \x01(\x02\x12!\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\x13.social.common.Date\x12\x0e\n\x06period\x18\x04 \x01(\x03\"\xa3\x01\n\rOrderShipping\x12\x15\n\rtracking_code\x18\x01 \x01(\t\x12\x13\n\x0bverify_code\x18\x02 \x01(\t\x12\'\n\x08\x64\x65livery\x18\x03 \x01(\x0b\x32\x15.social.shop.Delivery\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.social.shop.OrderStatus\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\xa2\x01\n\x0cOrderHistory\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12(\n\x06status\x18\x02 \x01(\x0e\x32\x18.social.shop.OrderStatus\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12-\n\x0bprev_status\x18\x05 \x01(\x0e\x32\x18.social.shop.OrderStatus\"\xb8\x03\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x07product\x18\x02 \x03(\x0b\x32\x18.social.shop.CartProduct\x12%\n\x07payment\x18\x03 \x01(\x0b\x32\x14.social.shop.Payment\x12\x13\n\x0btotal_price\x18\x04 \x01(\x01\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x14\n\x0c\x61\x64\x64ress_text\x18\x06 \x01(\t\x12/\n\x07\x61\x64\x64ress\x18\n \x01(\x0b\x32\x1e.social.account.AccountAddress\x12,\n\x08shipping\x18\x07 \x01(\x0b\x32\x1a.social.shop.OrderShipping\x12*\n\x07history\x18\x08 \x03(\x0b\x32\x19.social.shop.OrderHistory\x12&\n\x05owner\x18\t \x01(\x0b\x32\x17.social.account.Account\x12\'\n\x08\x64iscount\x18\x0b \x01(\x0b\x32\x15.social.shop.Discount\x12(\n\x06status\x18\x0c \x01(\x0e\x32\x18.social.shop.OrderStatus\x12\x0c\n\x04\x63ode\x18\r \x01(\t\".\n\tOrderList\x12!\n\x05items\x18\x01 \x03(\x0b\x32\x12.social.shop.Order\"C\n\x10GetPayUrlRequest\x12!\n\x05order\x18\x01 \x01(\x0b\x32\x12.social.shop.Order\x12\x0c\n\x04gate\x18\x02 \x01(\t\"!\n\x11GetPayUrlResponse\x12\x0c\n\x04link\x18\x01 \x01(\t\"(\n\x04Gate\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tis_active\x18\x02 \x01(\x08\",\n\x08GateList\x12 \n\x05items\x18\x01 \x03(\x0b\x32\x11.social.shop.Gate\"\xd2\x01\n\x08\x44iscount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\t\x12\x0f\n\x07percent\x18\x02 \x01(\x02\x12\x14\n\x0cmax_discount\x18\x03 \x01(\x02\x12*\n\x08\x63urrency\x18\x04 \x01(\x0e\x32\x18.social.product.Currency\x12\x11\n\tmax_usage\x18\x05 \x01(\x05\x12\x19\n\x11just_for_category\x18\x06 \x01(\t\x12\x18\n\x10just_for_product\x18\x07 \x01(\t\x12\x11\n\texpire_at\x18\x08 \x01(\x01\"4\n\x0c\x44iscountList\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.social.shop.Discount\"\x8e\x01\n\x0e\x44\x65positRequest\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\x12\x0e\n\x06mobile\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12*\n\x08\x63urrency\x18\x05 \x01(\x0e\x32\x18.social.product.Currency\x12\x0c\n\x04gate\x18\x06 \x01(\t\":\n\x0f\x44\x65positResponse\x12\x12\n\npayment_id\x18\x01 \x01(\t\x12\x13\n\x0bpayment_url\x18\x02 \x01(\t\"L\n\rWalletBalance\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x02\x12*\n\x08\x63urrency\x18\x02 \x01(\x0e\x32\x18.social.product.Currency\"\xdc\x01\n\x14\x43ompanyWalletHistory\x12.\n\rtransfer_from\x18\x01 \x01(\x0b\x32\x17.social.account.Account\x12,\n\x0btransfer_to\x18\x02 \x01(\x0b\x32\x17.social.account.Account\x12(\n\x07product\x18\x03 \x01(\x0b\x32\x17.social.product.Product\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x02\x12,\n\x04type\x18\x05 \x01(\x0e\x32\x1e.social.shop.WalletHistoryType\"L\n\x18\x43ompanyWalletHistoryList\x12\x30\n\x05items\x18\x01 \x03(\x0b\x32!.social.shop.CompanyWalletHistory\"\xae\x01\n\rWalletHistory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x02\x12*\n\x08\x63urrency\x18\x04 \x01(\x0e\x32\x18.social.product.Currency\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12,\n\x04type\x18\x06 \x01(\x0e\x32\x1e.social.shop.WalletHistoryType\">\n\x11WalletHistoryList\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.social.shop.WalletHistory\"\xc4\x02\n\x11WithdrawalRequest\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x02\x12/\n\x0b\x63redit_card\x18\x02 \x01(\x0b\x32\x1a.social.account.CreditCard\x12&\n\x05owner\x18\x03 \x01(\x0b\x32\x17.social.account.Account\x12*\n\x08\x63urrency\x18\x05 \x01(\x0e\x32\x18.social.product.Currency\x12?\n\x06status\x18\x06 \x01(\x0e\x32/.social.shop.WithdrawalRequest.WithdrawalStatus\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\"8\n\x10WithdrawalStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"?\n\x0eWithdrawalList\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x1e.social.shop.WithdrawalRequest\"z\n\x18GetAllWithdrawalsRequest\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.social.shop.WithdrawalRequest.WithdrawalStatus\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"(\n\x12WithdrawalResponse\x12\x12\n\npayment_id\x18\x01 \x01(\t\"g\n\x18\x41pproveWithdrawalRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x12\n\npayment_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0bis_approved\x18\x04 \x01(\x08\"$\n\x14ToggleGatewayRequest\x12\x0c\n\x04gate\x18\x01 \x01(\t\"G\n\x06Period\x12\x0e\n\x06period\x18\x01 \x01(\x05\x12\x14\n\x0c\x64\x65livery_day\x18\x02 \x01(\x05\x12\x17\n\x0f\x64\x65livery_period\x18\x03 \x01(\x05\"E\n\x08Schedule\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\x05\x12$\n\x07periods\x18\x02 \x03(\x0b\x32\x13.social.shop.Period\"X\n\x0eSellerSchedule\x12\x1d\n\x15is_holiday_day_active\x18\x01 \x01(\x08\x12\'\n\x08schedule\x18\x02 \x03(\x0b\x32\x15.social.shop.Schedule\")\n\x18GetSellerScheduleRequest\x12\r\n\x05owner\x18\x01 \x01(\t\"\x80\x01\n\x0bPreparation\x12\x0e\n\x06period\x18\x01 \x01(\x05\x12\"\n\x1a\x64\x61y_for_nearby_destination\x18\x02 \x01(\x05\x12!\n\x19\x64\x61y_for_other_destination\x18\x03 \x01(\x05\x12\x1a\n\x12preparation_period\x18\x04 \x01(\x05\"[\n\x15\x43ompanySchedulePeriod\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\x05\x12-\n\x0bpreparation\x18\x02 \x03(\x0b\x32\x18.social.shop.Preparation\"f\n\x0f\x43ompanySchedule\x12\x1d\n\x15is_holiday_day_active\x18\x01 \x01(\x08\x12\x34\n\x08schedule\x18\x02 \x03(\x0b\x32\".social.shop.CompanySchedulePeriod\"S\n\x0cPostCapacity\x12!\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x13.social.common.Date\x12\x0e\n\x06period\x18\x02 \x01(\x05\x12\x10\n\x08\x63\x61pacity\x18\x03 \x01(\x05\"<\n\x10PostCapacityList\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.social.shop.PostCapacity\"K\n\x16GetPostCapacityRequest\x12!\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x13.social.common.Date\x12\x0e\n\x06period\x18\x02 \x03(\x05\"J\n\x19GetScheduleForCartRequest\x12-\n\x0b\x64\x65stination\x18\x01 \x01(\x0e\x32\x18.social.shop.Destination\"Z\n\x0c\x44\x65liveryTime\x12!\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x13.social.common.Date\x12\'\n\x06period\x18\x02 \x03(\x0b\x32\x17.social.shop.PeriodInfo\";\n\x0fScheduleForCart\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.social.shop.DeliveryTime\">\n\nPeriodInfo\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nstart_time\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\t\"1\n\x07Periods\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.shop.PeriodInfo*\x99\x01\n\x0bOrderStatus\x12\x1e\n\x1aorder_status_default_value\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tDELIVERED\x10\x02\x12\r\n\tCANCELLED\x10\x03\x12\x0c\n\x08RETURNED\x10\x04\x12\t\n\x05READY\x10\x05\x12\r\n\tPACKAGING\x10\x06\x12\x08\n\x04SENT\x10\x07\x12\r\n\tIS_UNPAID\x10\t*`\n\x12OrderPaymentStatus\x12&\n\"order_payment_status_default_value\x10\x00\x12\n\n\x06UNPAID\x10\x01\x12\x08\n\x04PAID\x10\x02\x12\x0c\n\x08REFUNDED\x10\x03*+\n\rIncrementType\x12\x0c\n\x08\x44\x45\x43REASE\x10\x00\x12\x0c\n\x08INCREASE\x10\x01*(\n\rPaymentMethod\x12\n\n\x06WALLET\x10\x00\x12\x0b\n\x07GATEWAY\x10\x01*C\n\x11WalletHistoryType\x12\x0b\n\x07\x44\x45POSIT\x10\x00\x12\x0e\n\nWITHDRAWAL\x10\x01\x12\x07\n\x03\x42UY\x10\x02\x12\x08\n\x04SELL\x10\x03*$\n\x0b\x44\x65stination\x12\t\n\x05OTHER\x10\x00\x12\n\n\x06NEARBY\x10\x01\x32\xbc\x1a\n\x0bShopService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12\x42\n\x06Upsert\x12\x1a.social.shop.UpsertRequest\x1a\x1c.social.shop.InventoryInCart\x12\x37\n\x06\x44\x65lete\x12\x17.social.product.Product\x1a\x14.social.common.Empty\x12.\n\x03Get\x12\x14.social.common.Empty\x1a\x11.social.shop.Cart\x12<\n\x08\x43heckOut\x12\x1c.social.shop.CheckoutRequest\x1a\x12.social.shop.Order\x12I\n\nCheckOutV2\x12\x1c.social.shop.CheckoutRequest\x1a\x1d.social.shop.CheckoutResponse\x12G\n\x08PayOrder\x12\x1c.social.shop.PayOrderRequest\x1a\x1d.social.shop.PayOrderResponse\x12\x32\n\x08GetOrder\x12\x12.social.shop.Order\x1a\x12.social.shop.Order\x12<\n\x0cGetAllOrders\x12\x14.social.common.Empty\x1a\x16.social.shop.OrderList\x12R\n\x11GetOrdersByStatus\x12%.social.shop.GetOrdersByStatusRequest\x1a\x16.social.shop.OrderList\x12\x38\n\nGetPayment\x12\x14.social.shop.Payment\x1a\x14.social.shop.Payment\x12\x45\n\x0eGetAllPayments\x12\x19.social.common.Pagination\x1a\x18.social.shop.PaymentList\x12:\n\x0bGetAllGates\x12\x14.social.common.Empty\x1a\x15.social.shop.GateList\x12\x44\n\x07\x44\x65posit\x12\x1b.social.shop.DepositRequest\x1a\x1c.social.shop.DepositResponse\x12\x44\n\x10GetWalletBalance\x12\x14.social.common.Empty\x1a\x1a.social.shop.WalletBalance\x12M\n\x10GetWalletHistory\x12\x19.social.common.Pagination\x1a\x1e.social.shop.WalletHistoryList\x12M\n\nWithdrawal\x12\x1e.social.shop.WithdrawalRequest\x1a\x1f.social.shop.WithdrawalResponse\x12;\n\x0bGetDiscount\x12\x15.social.shop.Discount\x1a\x15.social.shop.Discount\x12[\n\x12GetInventoryInCart\x12#.social.shop.InventoryInCartRequest\x1a .social.shop.InventoryInCartList\x12[\n\x1dOwnerSetProductShippingStatus\x12$.social.shop.SetProductStatusRequest\x1a\x14.social.common.Empty\x12\x63\n!OwnerBulkSetProductShippingStatus\x12(.social.shop.BulkSetProductStatusRequest\x1a\x14.social.common.Empty\x12W\n\x16OwnerGetOrdersByStatus\x12%.social.shop.GetOrdersByStatusRequest\x1a\x16.social.shop.OrderList\x12W\n\x17\x41\x64minVerifyDeliveryCode\x12&.social.shop.VerifyDeliveryCodeRequest\x1a\x14.social.common.Empty\x12I\n\x14UpsertSellerSchedule\x12\x1b.social.shop.SellerSchedule\x1a\x14.social.common.Empty\x12W\n\x11GetSellerSchedule\x12%.social.shop.GetSellerScheduleRequest\x1a\x1b.social.shop.SellerSchedule\x12U\n\x0fGetPostCapacity\x12#.social.shop.GetPostCapacityRequest\x1a\x1d.social.shop.PostCapacityList\x12Z\n\x12GetScheduleForCart\x12&.social.shop.GetScheduleForCartRequest\x1a\x1c.social.shop.ScheduleForCart\x12\x38\n\nGetPeriods\x12\x14.social.common.Empty\x1a\x14.social.shop.Periods\x12\x43\n\x13\x41\x64minCreateDiscount\x12\x15.social.shop.Discount\x1a\x15.social.shop.Discount\x12\x43\n\x13\x41\x64minUpdateDiscount\x12\x15.social.shop.Discount\x1a\x15.social.shop.Discount\x12\x42\n\x13\x41\x64minDeleteDiscount\x12\x15.social.shop.Discount\x1a\x14.social.common.Empty\x12K\n\x13\x41\x64minGetAllDiscount\x12\x19.social.common.Pagination\x1a\x19.social.shop.DiscountList\x12]\n\x1e\x41\x64minApproveOrRejectWithdrawal\x12%.social.shop.ApproveWithdrawalRequest\x1a\x14.social.common.Empty\x12\x64\n\x1e\x41\x64minGetAllWithdrawalsRequests\x12%.social.shop.GetAllWithdrawalsRequest\x1a\x1b.social.shop.WithdrawalList\x12M\n\x12\x41\x64minToggleGateway\x12!.social.shop.ToggleGatewayRequest\x1a\x14.social.common.Empty\x12`\n\x1c\x41\x64minGetCompanyWalletHistory\x12\x19.social.common.Pagination\x1a%.social.shop.CompanyWalletHistoryList\x12P\n\x1c\x41\x64minGetCompanyWalletBalance\x12\x14.social.common.Empty\x1a\x1a.social.shop.WalletBalance\x12U\n\x1b\x41\x64minSetOrderShippingStatus\x12\".social.shop.SetOrderStatusRequest\x1a\x12.social.shop.Order\x12\x46\n\x11\x41\x64minGetAllOrders\x12\x19.social.common.Pagination\x1a\x16.social.shop.OrderList\x12P\n\x1a\x41\x64minUpsertCompanySchedule\x12\x1c.social.shop.CompanySchedule\x1a\x14.social.common.Empty\x12M\n\x17\x41\x64minGetCompanySchedule\x12\x14.social.common.Empty\x1a\x1c.social.shop.CompanySchedule\x12J\n\x17\x41\x64minUpsertPostCapacity\x12\x19.social.shop.PostCapacity\x1a\x14.social.common.Empty\x12[\n\x1d\x41\x64minSetProductShippingStatus\x12$.social.shop.SetProductStatusRequest\x1a\x14.social.common.Empty\x12\x63\n!AdminBulkSetProductShippingStatus\x12(.social.shop.BulkSetProductStatusRequest\x1a\x14.social.common.Emptyb\x06proto3')

_ORDERSTATUS = DESCRIPTOR.enum_types_by_name['OrderStatus']
OrderStatus = enum_type_wrapper.EnumTypeWrapper(_ORDERSTATUS)
_ORDERPAYMENTSTATUS = DESCRIPTOR.enum_types_by_name['OrderPaymentStatus']
OrderPaymentStatus = enum_type_wrapper.EnumTypeWrapper(_ORDERPAYMENTSTATUS)
_INCREMENTTYPE = DESCRIPTOR.enum_types_by_name['IncrementType']
IncrementType = enum_type_wrapper.EnumTypeWrapper(_INCREMENTTYPE)
_PAYMENTMETHOD = DESCRIPTOR.enum_types_by_name['PaymentMethod']
PaymentMethod = enum_type_wrapper.EnumTypeWrapper(_PAYMENTMETHOD)
_WALLETHISTORYTYPE = DESCRIPTOR.enum_types_by_name['WalletHistoryType']
WalletHistoryType = enum_type_wrapper.EnumTypeWrapper(_WALLETHISTORYTYPE)
_DESTINATION = DESCRIPTOR.enum_types_by_name['Destination']
Destination = enum_type_wrapper.EnumTypeWrapper(_DESTINATION)
order_status_default_value = 0
PENDING = 1
DELIVERED = 2
CANCELLED = 3
RETURNED = 4
READY = 5
PACKAGING = 6
SENT = 7
IS_UNPAID = 9
order_payment_status_default_value = 0
UNPAID = 1
PAID = 2
REFUNDED = 3
DECREASE = 0
INCREASE = 1
WALLET = 0
GATEWAY = 1
DEPOSIT = 0
WITHDRAWAL = 1
BUY = 2
SELL = 3
OTHER = 0
NEARBY = 1


_VERIFYDELIVERYCODEREQUEST = DESCRIPTOR.message_types_by_name['VerifyDeliveryCodeRequest']
_CARTPRODUCTSELLERSTATUS = DESCRIPTOR.message_types_by_name['CartProductSellerStatus']
_GETORDERSBYSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetOrdersByStatusRequest']
_SETORDERSTATUSREQUEST = DESCRIPTOR.message_types_by_name['SetOrderStatusRequest']
_SETPRODUCTSTATUSREQUEST = DESCRIPTOR.message_types_by_name['SetProductStatusRequest']
_BULKPRODUCTS = DESCRIPTOR.message_types_by_name['BulkProducts']
_BULKSETPRODUCTSTATUSREQUEST = DESCRIPTOR.message_types_by_name['BulkSetProductStatusRequest']
_INVENTORYINCARTREQUEST = DESCRIPTOR.message_types_by_name['InventoryInCartRequest']
_INVENTORYINCART = DESCRIPTOR.message_types_by_name['InventoryInCart']
_INVENTORYINCARTLIST = DESCRIPTOR.message_types_by_name['InventoryInCartList']
_UPSERTREQUEST = DESCRIPTOR.message_types_by_name['UpsertRequest']
_CARTPRODUCT = DESCRIPTOR.message_types_by_name['CartProduct']
_CART = DESCRIPTOR.message_types_by_name['Cart']
_CHECKOUTREQUEST = DESCRIPTOR.message_types_by_name['CheckoutRequest']
_PAYORDERREQUEST = DESCRIPTOR.message_types_by_name['PayOrderRequest']
_PAYORDERRESPONSE = DESCRIPTOR.message_types_by_name['PayOrderResponse']
_CHECKOUTRESPONSE = DESCRIPTOR.message_types_by_name['CheckoutResponse']
_PAYMENT = DESCRIPTOR.message_types_by_name['Payment']
_PAYMENTLIST = DESCRIPTOR.message_types_by_name['PaymentList']
_DELIVERY = DESCRIPTOR.message_types_by_name['Delivery']
_ORDERSHIPPING = DESCRIPTOR.message_types_by_name['OrderShipping']
_ORDERHISTORY = DESCRIPTOR.message_types_by_name['OrderHistory']
_ORDER = DESCRIPTOR.message_types_by_name['Order']
_ORDERLIST = DESCRIPTOR.message_types_by_name['OrderList']
_GETPAYURLREQUEST = DESCRIPTOR.message_types_by_name['GetPayUrlRequest']
_GETPAYURLRESPONSE = DESCRIPTOR.message_types_by_name['GetPayUrlResponse']
_GATE = DESCRIPTOR.message_types_by_name['Gate']
_GATELIST = DESCRIPTOR.message_types_by_name['GateList']
_DISCOUNT = DESCRIPTOR.message_types_by_name['Discount']
_DISCOUNTLIST = DESCRIPTOR.message_types_by_name['DiscountList']
_DEPOSITREQUEST = DESCRIPTOR.message_types_by_name['DepositRequest']
_DEPOSITRESPONSE = DESCRIPTOR.message_types_by_name['DepositResponse']
_WALLETBALANCE = DESCRIPTOR.message_types_by_name['WalletBalance']
_COMPANYWALLETHISTORY = DESCRIPTOR.message_types_by_name['CompanyWalletHistory']
_COMPANYWALLETHISTORYLIST = DESCRIPTOR.message_types_by_name['CompanyWalletHistoryList']
_WALLETHISTORY = DESCRIPTOR.message_types_by_name['WalletHistory']
_WALLETHISTORYLIST = DESCRIPTOR.message_types_by_name['WalletHistoryList']
_WITHDRAWALREQUEST = DESCRIPTOR.message_types_by_name['WithdrawalRequest']
_WITHDRAWALLIST = DESCRIPTOR.message_types_by_name['WithdrawalList']
_GETALLWITHDRAWALSREQUEST = DESCRIPTOR.message_types_by_name['GetAllWithdrawalsRequest']
_WITHDRAWALRESPONSE = DESCRIPTOR.message_types_by_name['WithdrawalResponse']
_APPROVEWITHDRAWALREQUEST = DESCRIPTOR.message_types_by_name['ApproveWithdrawalRequest']
_TOGGLEGATEWAYREQUEST = DESCRIPTOR.message_types_by_name['ToggleGatewayRequest']
_PERIOD = DESCRIPTOR.message_types_by_name['Period']
_SCHEDULE = DESCRIPTOR.message_types_by_name['Schedule']
_SELLERSCHEDULE = DESCRIPTOR.message_types_by_name['SellerSchedule']
_GETSELLERSCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['GetSellerScheduleRequest']
_PREPARATION = DESCRIPTOR.message_types_by_name['Preparation']
_COMPANYSCHEDULEPERIOD = DESCRIPTOR.message_types_by_name['CompanySchedulePeriod']
_COMPANYSCHEDULE = DESCRIPTOR.message_types_by_name['CompanySchedule']
_POSTCAPACITY = DESCRIPTOR.message_types_by_name['PostCapacity']
_POSTCAPACITYLIST = DESCRIPTOR.message_types_by_name['PostCapacityList']
_GETPOSTCAPACITYREQUEST = DESCRIPTOR.message_types_by_name['GetPostCapacityRequest']
_GETSCHEDULEFORCARTREQUEST = DESCRIPTOR.message_types_by_name['GetScheduleForCartRequest']
_DELIVERYTIME = DESCRIPTOR.message_types_by_name['DeliveryTime']
_SCHEDULEFORCART = DESCRIPTOR.message_types_by_name['ScheduleForCart']
_PERIODINFO = DESCRIPTOR.message_types_by_name['PeriodInfo']
_PERIODS = DESCRIPTOR.message_types_by_name['Periods']
_PAYMENT_PAYMENTSTATUS = _PAYMENT.enum_types_by_name['PaymentStatus']
_WITHDRAWALREQUEST_WITHDRAWALSTATUS = _WITHDRAWALREQUEST.enum_types_by_name['WithdrawalStatus']
VerifyDeliveryCodeRequest = _reflection.GeneratedProtocolMessageType('VerifyDeliveryCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYDELIVERYCODEREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.VerifyDeliveryCodeRequest)
  })
_sym_db.RegisterMessage(VerifyDeliveryCodeRequest)

CartProductSellerStatus = _reflection.GeneratedProtocolMessageType('CartProductSellerStatus', (_message.Message,), {
  'DESCRIPTOR' : _CARTPRODUCTSELLERSTATUS,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CartProductSellerStatus)
  })
_sym_db.RegisterMessage(CartProductSellerStatus)

GetOrdersByStatusRequest = _reflection.GeneratedProtocolMessageType('GetOrdersByStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORDERSBYSTATUSREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GetOrdersByStatusRequest)
  })
_sym_db.RegisterMessage(GetOrdersByStatusRequest)

SetOrderStatusRequest = _reflection.GeneratedProtocolMessageType('SetOrderStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETORDERSTATUSREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.SetOrderStatusRequest)
  })
_sym_db.RegisterMessage(SetOrderStatusRequest)

SetProductStatusRequest = _reflection.GeneratedProtocolMessageType('SetProductStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPRODUCTSTATUSREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.SetProductStatusRequest)
  })
_sym_db.RegisterMessage(SetProductStatusRequest)

BulkProducts = _reflection.GeneratedProtocolMessageType('BulkProducts', (_message.Message,), {
  'DESCRIPTOR' : _BULKPRODUCTS,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.BulkProducts)
  })
_sym_db.RegisterMessage(BulkProducts)

BulkSetProductStatusRequest = _reflection.GeneratedProtocolMessageType('BulkSetProductStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _BULKSETPRODUCTSTATUSREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.BulkSetProductStatusRequest)
  })
_sym_db.RegisterMessage(BulkSetProductStatusRequest)

InventoryInCartRequest = _reflection.GeneratedProtocolMessageType('InventoryInCartRequest', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYINCARTREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.InventoryInCartRequest)
  })
_sym_db.RegisterMessage(InventoryInCartRequest)

InventoryInCart = _reflection.GeneratedProtocolMessageType('InventoryInCart', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYINCART,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.InventoryInCart)
  })
_sym_db.RegisterMessage(InventoryInCart)

InventoryInCartList = _reflection.GeneratedProtocolMessageType('InventoryInCartList', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYINCARTLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.InventoryInCartList)
  })
_sym_db.RegisterMessage(InventoryInCartList)

UpsertRequest = _reflection.GeneratedProtocolMessageType('UpsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPSERTREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.UpsertRequest)
  })
_sym_db.RegisterMessage(UpsertRequest)

CartProduct = _reflection.GeneratedProtocolMessageType('CartProduct', (_message.Message,), {
  'DESCRIPTOR' : _CARTPRODUCT,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CartProduct)
  })
_sym_db.RegisterMessage(CartProduct)

Cart = _reflection.GeneratedProtocolMessageType('Cart', (_message.Message,), {
  'DESCRIPTOR' : _CART,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Cart)
  })
_sym_db.RegisterMessage(Cart)

CheckoutRequest = _reflection.GeneratedProtocolMessageType('CheckoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKOUTREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CheckoutRequest)
  })
_sym_db.RegisterMessage(CheckoutRequest)

PayOrderRequest = _reflection.GeneratedProtocolMessageType('PayOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAYORDERREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.PayOrderRequest)
  })
_sym_db.RegisterMessage(PayOrderRequest)

PayOrderResponse = _reflection.GeneratedProtocolMessageType('PayOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAYORDERRESPONSE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.PayOrderResponse)
  })
_sym_db.RegisterMessage(PayOrderResponse)

CheckoutResponse = _reflection.GeneratedProtocolMessageType('CheckoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKOUTRESPONSE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CheckoutResponse)
  })
_sym_db.RegisterMessage(CheckoutResponse)

Payment = _reflection.GeneratedProtocolMessageType('Payment', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENT,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Payment)
  })
_sym_db.RegisterMessage(Payment)

PaymentList = _reflection.GeneratedProtocolMessageType('PaymentList', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.PaymentList)
  })
_sym_db.RegisterMessage(PaymentList)

Delivery = _reflection.GeneratedProtocolMessageType('Delivery', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERY,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Delivery)
  })
_sym_db.RegisterMessage(Delivery)

OrderShipping = _reflection.GeneratedProtocolMessageType('OrderShipping', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSHIPPING,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.OrderShipping)
  })
_sym_db.RegisterMessage(OrderShipping)

OrderHistory = _reflection.GeneratedProtocolMessageType('OrderHistory', (_message.Message,), {
  'DESCRIPTOR' : _ORDERHISTORY,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.OrderHistory)
  })
_sym_db.RegisterMessage(OrderHistory)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {
  'DESCRIPTOR' : _ORDER,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Order)
  })
_sym_db.RegisterMessage(Order)

OrderList = _reflection.GeneratedProtocolMessageType('OrderList', (_message.Message,), {
  'DESCRIPTOR' : _ORDERLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.OrderList)
  })
_sym_db.RegisterMessage(OrderList)

GetPayUrlRequest = _reflection.GeneratedProtocolMessageType('GetPayUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPAYURLREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GetPayUrlRequest)
  })
_sym_db.RegisterMessage(GetPayUrlRequest)

GetPayUrlResponse = _reflection.GeneratedProtocolMessageType('GetPayUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPAYURLRESPONSE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GetPayUrlResponse)
  })
_sym_db.RegisterMessage(GetPayUrlResponse)

Gate = _reflection.GeneratedProtocolMessageType('Gate', (_message.Message,), {
  'DESCRIPTOR' : _GATE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Gate)
  })
_sym_db.RegisterMessage(Gate)

GateList = _reflection.GeneratedProtocolMessageType('GateList', (_message.Message,), {
  'DESCRIPTOR' : _GATELIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GateList)
  })
_sym_db.RegisterMessage(GateList)

Discount = _reflection.GeneratedProtocolMessageType('Discount', (_message.Message,), {
  'DESCRIPTOR' : _DISCOUNT,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Discount)
  })
_sym_db.RegisterMessage(Discount)

DiscountList = _reflection.GeneratedProtocolMessageType('DiscountList', (_message.Message,), {
  'DESCRIPTOR' : _DISCOUNTLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.DiscountList)
  })
_sym_db.RegisterMessage(DiscountList)

DepositRequest = _reflection.GeneratedProtocolMessageType('DepositRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSITREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.DepositRequest)
  })
_sym_db.RegisterMessage(DepositRequest)

DepositResponse = _reflection.GeneratedProtocolMessageType('DepositResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSITRESPONSE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.DepositResponse)
  })
_sym_db.RegisterMessage(DepositResponse)

WalletBalance = _reflection.GeneratedProtocolMessageType('WalletBalance', (_message.Message,), {
  'DESCRIPTOR' : _WALLETBALANCE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.WalletBalance)
  })
_sym_db.RegisterMessage(WalletBalance)

CompanyWalletHistory = _reflection.GeneratedProtocolMessageType('CompanyWalletHistory', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYWALLETHISTORY,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CompanyWalletHistory)
  })
_sym_db.RegisterMessage(CompanyWalletHistory)

CompanyWalletHistoryList = _reflection.GeneratedProtocolMessageType('CompanyWalletHistoryList', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYWALLETHISTORYLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CompanyWalletHistoryList)
  })
_sym_db.RegisterMessage(CompanyWalletHistoryList)

WalletHistory = _reflection.GeneratedProtocolMessageType('WalletHistory', (_message.Message,), {
  'DESCRIPTOR' : _WALLETHISTORY,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.WalletHistory)
  })
_sym_db.RegisterMessage(WalletHistory)

WalletHistoryList = _reflection.GeneratedProtocolMessageType('WalletHistoryList', (_message.Message,), {
  'DESCRIPTOR' : _WALLETHISTORYLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.WalletHistoryList)
  })
_sym_db.RegisterMessage(WalletHistoryList)

WithdrawalRequest = _reflection.GeneratedProtocolMessageType('WithdrawalRequest', (_message.Message,), {
  'DESCRIPTOR' : _WITHDRAWALREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.WithdrawalRequest)
  })
_sym_db.RegisterMessage(WithdrawalRequest)

WithdrawalList = _reflection.GeneratedProtocolMessageType('WithdrawalList', (_message.Message,), {
  'DESCRIPTOR' : _WITHDRAWALLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.WithdrawalList)
  })
_sym_db.RegisterMessage(WithdrawalList)

GetAllWithdrawalsRequest = _reflection.GeneratedProtocolMessageType('GetAllWithdrawalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLWITHDRAWALSREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GetAllWithdrawalsRequest)
  })
_sym_db.RegisterMessage(GetAllWithdrawalsRequest)

WithdrawalResponse = _reflection.GeneratedProtocolMessageType('WithdrawalResponse', (_message.Message,), {
  'DESCRIPTOR' : _WITHDRAWALRESPONSE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.WithdrawalResponse)
  })
_sym_db.RegisterMessage(WithdrawalResponse)

ApproveWithdrawalRequest = _reflection.GeneratedProtocolMessageType('ApproveWithdrawalRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEWITHDRAWALREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.ApproveWithdrawalRequest)
  })
_sym_db.RegisterMessage(ApproveWithdrawalRequest)

ToggleGatewayRequest = _reflection.GeneratedProtocolMessageType('ToggleGatewayRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEGATEWAYREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.ToggleGatewayRequest)
  })
_sym_db.RegisterMessage(ToggleGatewayRequest)

Period = _reflection.GeneratedProtocolMessageType('Period', (_message.Message,), {
  'DESCRIPTOR' : _PERIOD,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Period)
  })
_sym_db.RegisterMessage(Period)

Schedule = _reflection.GeneratedProtocolMessageType('Schedule', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Schedule)
  })
_sym_db.RegisterMessage(Schedule)

SellerSchedule = _reflection.GeneratedProtocolMessageType('SellerSchedule', (_message.Message,), {
  'DESCRIPTOR' : _SELLERSCHEDULE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.SellerSchedule)
  })
_sym_db.RegisterMessage(SellerSchedule)

GetSellerScheduleRequest = _reflection.GeneratedProtocolMessageType('GetSellerScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSELLERSCHEDULEREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GetSellerScheduleRequest)
  })
_sym_db.RegisterMessage(GetSellerScheduleRequest)

Preparation = _reflection.GeneratedProtocolMessageType('Preparation', (_message.Message,), {
  'DESCRIPTOR' : _PREPARATION,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Preparation)
  })
_sym_db.RegisterMessage(Preparation)

CompanySchedulePeriod = _reflection.GeneratedProtocolMessageType('CompanySchedulePeriod', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYSCHEDULEPERIOD,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CompanySchedulePeriod)
  })
_sym_db.RegisterMessage(CompanySchedulePeriod)

CompanySchedule = _reflection.GeneratedProtocolMessageType('CompanySchedule', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYSCHEDULE,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.CompanySchedule)
  })
_sym_db.RegisterMessage(CompanySchedule)

PostCapacity = _reflection.GeneratedProtocolMessageType('PostCapacity', (_message.Message,), {
  'DESCRIPTOR' : _POSTCAPACITY,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.PostCapacity)
  })
_sym_db.RegisterMessage(PostCapacity)

PostCapacityList = _reflection.GeneratedProtocolMessageType('PostCapacityList', (_message.Message,), {
  'DESCRIPTOR' : _POSTCAPACITYLIST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.PostCapacityList)
  })
_sym_db.RegisterMessage(PostCapacityList)

GetPostCapacityRequest = _reflection.GeneratedProtocolMessageType('GetPostCapacityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTCAPACITYREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GetPostCapacityRequest)
  })
_sym_db.RegisterMessage(GetPostCapacityRequest)

GetScheduleForCartRequest = _reflection.GeneratedProtocolMessageType('GetScheduleForCartRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEDULEFORCARTREQUEST,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.GetScheduleForCartRequest)
  })
_sym_db.RegisterMessage(GetScheduleForCartRequest)

DeliveryTime = _reflection.GeneratedProtocolMessageType('DeliveryTime', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYTIME,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.DeliveryTime)
  })
_sym_db.RegisterMessage(DeliveryTime)

ScheduleForCart = _reflection.GeneratedProtocolMessageType('ScheduleForCart', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEFORCART,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.ScheduleForCart)
  })
_sym_db.RegisterMessage(ScheduleForCart)

PeriodInfo = _reflection.GeneratedProtocolMessageType('PeriodInfo', (_message.Message,), {
  'DESCRIPTOR' : _PERIODINFO,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.PeriodInfo)
  })
_sym_db.RegisterMessage(PeriodInfo)

Periods = _reflection.GeneratedProtocolMessageType('Periods', (_message.Message,), {
  'DESCRIPTOR' : _PERIODS,
  '__module__' : 'services.shop.shop_pb2'
  # @@protoc_insertion_point(class_scope:social.shop.Periods)
  })
_sym_db.RegisterMessage(Periods)

_SHOPSERVICE = DESCRIPTOR.services_by_name['ShopService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ORDERSTATUS._serialized_start=6364
  _ORDERSTATUS._serialized_end=6517
  _ORDERPAYMENTSTATUS._serialized_start=6519
  _ORDERPAYMENTSTATUS._serialized_end=6615
  _INCREMENTTYPE._serialized_start=6617
  _INCREMENTTYPE._serialized_end=6660
  _PAYMENTMETHOD._serialized_start=6662
  _PAYMENTMETHOD._serialized_end=6702
  _WALLETHISTORYTYPE._serialized_start=6704
  _WALLETHISTORYTYPE._serialized_end=6771
  _DESTINATION._serialized_start=6773
  _DESTINATION._serialized_end=6809
  _VERIFYDELIVERYCODEREQUEST._serialized_start=135
  _VERIFYDELIVERYCODEREQUEST._serialized_end=176
  _CARTPRODUCTSELLERSTATUS._serialized_start=178
  _CARTPRODUCTSELLERSTATUS._serialized_end=283
  _GETORDERSBYSTATUSREQUEST._serialized_start=286
  _GETORDERSBYSTATUSREQUEST._serialized_end=468
  _SETORDERSTATUSREQUEST._serialized_start=470
  _SETORDERSTATUSREQUEST._serialized_end=592
  _SETPRODUCTSTATUSREQUEST._serialized_start=595
  _SETPRODUCTSTATUSREQUEST._serialized_end=740
  _BULKPRODUCTS._serialized_start=742
  _BULKPRODUCTS._serialized_end=858
  _BULKSETPRODUCTSTATUSREQUEST._serialized_start=860
  _BULKSETPRODUCTSTATUSREQUEST._serialized_end=952
  _INVENTORYINCARTREQUEST._serialized_start=954
  _INVENTORYINCARTREQUEST._serialized_end=1020
  _INVENTORYINCART._serialized_start=1022
  _INVENTORYINCART._serialized_end=1077
  _INVENTORYINCARTLIST._serialized_start=1079
  _INVENTORYINCARTLIST._serialized_end=1145
  _UPSERTREQUEST._serialized_start=1147
  _UPSERTREQUEST._serialized_end=1247
  _CARTPRODUCT._serialized_start=1250
  _CARTPRODUCT._serialized_end=1446
  _CART._serialized_start=1448
  _CART._serialized_end=1513
  _CHECKOUTREQUEST._serialized_start=1516
  _CHECKOUTREQUEST._serialized_end=1664
  _PAYORDERREQUEST._serialized_start=1666
  _PAYORDERREQUEST._serialized_end=1753
  _PAYORDERRESPONSE._serialized_start=1755
  _PAYORDERRESPONSE._serialized_end=1851
  _CHECKOUTRESPONSE._serialized_start=1853
  _CHECKOUTRESPONSE._serialized_end=1946
  _PAYMENT._serialized_start=1949
  _PAYMENT._serialized_end=2235
  _PAYMENT_PAYMENTSTATUS._serialized_start=2182
  _PAYMENT_PAYMENTSTATUS._serialized_end=2235
  _PAYMENTLIST._serialized_start=2237
  _PAYMENTLIST._serialized_end=2287
  _DELIVERY._serialized_start=2289
  _DELIVERY._serialized_end=2381
  _ORDERSHIPPING._serialized_start=2384
  _ORDERSHIPPING._serialized_end=2547
  _ORDERHISTORY._serialized_start=2550
  _ORDERHISTORY._serialized_end=2712
  _ORDER._serialized_start=2715
  _ORDER._serialized_end=3155
  _ORDERLIST._serialized_start=3157
  _ORDERLIST._serialized_end=3203
  _GETPAYURLREQUEST._serialized_start=3205
  _GETPAYURLREQUEST._serialized_end=3272
  _GETPAYURLRESPONSE._serialized_start=3274
  _GETPAYURLRESPONSE._serialized_end=3307
  _GATE._serialized_start=3309
  _GATE._serialized_end=3349
  _GATELIST._serialized_start=3351
  _GATELIST._serialized_end=3395
  _DISCOUNT._serialized_start=3398
  _DISCOUNT._serialized_end=3608
  _DISCOUNTLIST._serialized_start=3610
  _DISCOUNTLIST._serialized_end=3662
  _DEPOSITREQUEST._serialized_start=3665
  _DEPOSITREQUEST._serialized_end=3807
  _DEPOSITRESPONSE._serialized_start=3809
  _DEPOSITRESPONSE._serialized_end=3867
  _WALLETBALANCE._serialized_start=3869
  _WALLETBALANCE._serialized_end=3945
  _COMPANYWALLETHISTORY._serialized_start=3948
  _COMPANYWALLETHISTORY._serialized_end=4168
  _COMPANYWALLETHISTORYLIST._serialized_start=4170
  _COMPANYWALLETHISTORYLIST._serialized_end=4246
  _WALLETHISTORY._serialized_start=4249
  _WALLETHISTORY._serialized_end=4423
  _WALLETHISTORYLIST._serialized_start=4425
  _WALLETHISTORYLIST._serialized_end=4487
  _WITHDRAWALREQUEST._serialized_start=4490
  _WITHDRAWALREQUEST._serialized_end=4814
  _WITHDRAWALREQUEST_WITHDRAWALSTATUS._serialized_start=4758
  _WITHDRAWALREQUEST_WITHDRAWALSTATUS._serialized_end=4814
  _WITHDRAWALLIST._serialized_start=4816
  _WITHDRAWALLIST._serialized_end=4879
  _GETALLWITHDRAWALSREQUEST._serialized_start=4881
  _GETALLWITHDRAWALSREQUEST._serialized_end=5003
  _WITHDRAWALRESPONSE._serialized_start=5005
  _WITHDRAWALRESPONSE._serialized_end=5045
  _APPROVEWITHDRAWALREQUEST._serialized_start=5047
  _APPROVEWITHDRAWALREQUEST._serialized_end=5150
  _TOGGLEGATEWAYREQUEST._serialized_start=5152
  _TOGGLEGATEWAYREQUEST._serialized_end=5188
  _PERIOD._serialized_start=5190
  _PERIOD._serialized_end=5261
  _SCHEDULE._serialized_start=5263
  _SCHEDULE._serialized_end=5332
  _SELLERSCHEDULE._serialized_start=5334
  _SELLERSCHEDULE._serialized_end=5422
  _GETSELLERSCHEDULEREQUEST._serialized_start=5424
  _GETSELLERSCHEDULEREQUEST._serialized_end=5465
  _PREPARATION._serialized_start=5468
  _PREPARATION._serialized_end=5596
  _COMPANYSCHEDULEPERIOD._serialized_start=5598
  _COMPANYSCHEDULEPERIOD._serialized_end=5689
  _COMPANYSCHEDULE._serialized_start=5691
  _COMPANYSCHEDULE._serialized_end=5793
  _POSTCAPACITY._serialized_start=5795
  _POSTCAPACITY._serialized_end=5878
  _POSTCAPACITYLIST._serialized_start=5880
  _POSTCAPACITYLIST._serialized_end=5940
  _GETPOSTCAPACITYREQUEST._serialized_start=5942
  _GETPOSTCAPACITYREQUEST._serialized_end=6017
  _GETSCHEDULEFORCARTREQUEST._serialized_start=6019
  _GETSCHEDULEFORCARTREQUEST._serialized_end=6093
  _DELIVERYTIME._serialized_start=6095
  _DELIVERYTIME._serialized_end=6185
  _SCHEDULEFORCART._serialized_start=6187
  _SCHEDULEFORCART._serialized_end=6246
  _PERIODINFO._serialized_start=6248
  _PERIODINFO._serialized_end=6310
  _PERIODS._serialized_start=6312
  _PERIODS._serialized_end=6361
  _SHOPSERVICE._serialized_start=6812
  _SHOPSERVICE._serialized_end=10200
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/hashtag/hashtag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.post import post_pb2 as services_dot_post_dot_post__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/hashtag/hashtag.proto\x12\x0esocial.hashtag\x1a\x1cservices/common/common.proto\x1a\x18services/post/post.proto\x1a\x1eservices/account/account.proto\"v\n\x07Hashtag\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x11\n\tbanned_at\x18\x04 \x01(\x03\x12)\n\x04stat\x18\x05 \x01(\x0b\x32\x1b.social.hashtag.HashtagStat\"P\n\x0bHashtagStat\x12\x14\n\x0ctagged_count\x18\x01 \x01(\x03\x12\x14\n\x0cis_following\x18\x02 \x01(\x05\x12\x15\n\rcount_to_text\x18\x03 \x01(\t\"6\n\x0c\x46indResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\"Y\n\x0eGetFeedRequest\x12(\n\x07hashtag\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"]\n\x0fGetFeedResponse\x12(\n\x07hashtag\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\x12 \n\x05items\x18\x02 \x03(\x0b\x32\x11.social.post.Post\"E\n\x1bGetHashtagFollowingResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\"2\n\rToggleHashtag\x12\x12\n\nhashtag_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x32\xc0\x04\n\x0eHashtagService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12@\n\x04\x46ind\x12\x1a.social.common.FindRequest\x1a\x1c.social.hashtag.FindResponse\x12\x37\n\x06\x46ollow\x12\x17.social.hashtag.Hashtag\x1a\x14.social.common.Empty\x12\x39\n\x08Unfollow\x12\x17.social.hashtag.Hashtag\x1a\x14.social.common.Empty\x12J\n\x07GetFeed\x12\x1e.social.hashtag.GetFeedRequest\x1a\x1f.social.hashtag.GetFeedResponse\x12\x66\n\x13GetHashtagFollowing\x12\".social.account.AccountListRequest\x1a+.social.hashtag.GetHashtagFollowingResponse\x12I\n\x12\x41\x64minHashtagDelete\x12\x1d.social.hashtag.ToggleHashtag\x1a\x14.social.common.Empty\x12\x46\n\x0f\x41\x64minHashtagBan\x12\x1d.social.hashtag.ToggleHashtag\x1a\x14.social.common.Emptyb\x06proto3')



_HASHTAG = DESCRIPTOR.message_types_by_name['Hashtag']
_HASHTAGSTAT = DESCRIPTOR.message_types_by_name['HashtagStat']
_FINDRESPONSE = DESCRIPTOR.message_types_by_name['FindResponse']
_GETFEEDREQUEST = DESCRIPTOR.message_types_by_name['GetFeedRequest']
_GETFEEDRESPONSE = DESCRIPTOR.message_types_by_name['GetFeedResponse']
_GETHASHTAGFOLLOWINGRESPONSE = DESCRIPTOR.message_types_by_name['GetHashtagFollowingResponse']
_TOGGLEHASHTAG = DESCRIPTOR.message_types_by_name['ToggleHashtag']
Hashtag = _reflection.GeneratedProtocolMessageType('Hashtag', (_message.Message,), {
  'DESCRIPTOR' : _HASHTAG,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.Hashtag)
  })
_sym_db.RegisterMessage(Hashtag)

HashtagStat = _reflection.GeneratedProtocolMessageType('HashtagStat', (_message.Message,), {
  'DESCRIPTOR' : _HASHTAGSTAT,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.HashtagStat)
  })
_sym_db.RegisterMessage(HashtagStat)

FindResponse = _reflection.GeneratedProtocolMessageType('FindResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDRESPONSE,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.FindResponse)
  })
_sym_db.RegisterMessage(FindResponse)

GetFeedRequest = _reflection.GeneratedProtocolMessageType('GetFeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEEDREQUEST,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.GetFeedRequest)
  })
_sym_db.RegisterMessage(GetFeedRequest)

GetFeedResponse = _reflection.GeneratedProtocolMessageType('GetFeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEEDRESPONSE,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.GetFeedResponse)
  })
_sym_db.RegisterMessage(GetFeedResponse)

GetHashtagFollowingResponse = _reflection.GeneratedProtocolMessageType('GetHashtagFollowingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETHASHTAGFOLLOWINGRESPONSE,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.GetHashtagFollowingResponse)
  })
_sym_db.RegisterMessage(GetHashtagFollowingResponse)

ToggleHashtag = _reflection.GeneratedProtocolMessageType('ToggleHashtag', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEHASHTAG,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.ToggleHashtag)
  })
_sym_db.RegisterMessage(ToggleHashtag)

_HASHTAGSERVICE = DESCRIPTOR.services_by_name['HashtagService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HASHTAG._serialized_start=138
  _HASHTAG._serialized_end=256
  _HASHTAGSTAT._serialized_start=258
  _HASHTAGSTAT._serialized_end=338
  _FINDRESPONSE._serialized_start=340
  _FINDRESPONSE._serialized_end=394
  _GETFEEDREQUEST._serialized_start=396
  _GETFEEDREQUEST._serialized_end=485
  _GETFEEDRESPONSE._serialized_start=487
  _GETFEEDRESPONSE._serialized_end=580
  _GETHASHTAGFOLLOWINGRESPONSE._serialized_start=582
  _GETHASHTAGFOLLOWINGRESPONSE._serialized_end=651
  _TOGGLEHASHTAG._serialized_start=653
  _TOGGLEHASHTAG._serialized_end=703
  _HASHTAGSERVICE._serialized_start=706
  _HASHTAGSERVICE._serialized_end=1282
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/discussion/discussion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$services/discussion/discussion.proto\x12\x06social\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\"\xe9\x01\n\nDiscussion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x11\n\tparent_id\x18\x03 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x04 \x01(\x0b\x32\x17.social.account.Account\x12\x0c\n\x04\x62ody\x18\x05 \x01(\t\x12\x14\n\x0cpublished_at\x18\x06 \x01(\x03\x12\x12\n\ndeleted_at\x18\x07 \x01(\x03\x12$\n\x04stat\x18\x08 \x01(\x0b\x32\x16.social.DiscussionStat\x12\x10\n\x08is_liked\x18\t \x01(\x08\x12\x11\n\tis_pinned\x18\n \x01(\x08\"9\n\x0e\x44iscussionStat\x12\x12\n\nlike_count\x18\x01 \x01(\x03\x12\x13\n\x0breply_count\x18\x02 \x01(\x03\";\n\x16\x44iscussionListResponse\x12!\n\x05items\x18\x01 \x03(\x0b\x32\x12.social.Discussion\"Z\n\x15GetDiscussionsRequest\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\"8\n\x10ToggleDiscussion\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x32\x89\x05\n\x11\x44iscussionService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12\x31\n\x07Publish\x12\x12.social.Discussion\x1a\x12.social.Discussion\x12\x32\n\x06Update\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12\x32\n\x06\x44\x65lete\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12O\n\x0eGetDiscussions\x12\x1d.social.GetDiscussionsRequest\x1a\x1e.social.DiscussionListResponse\x12\x30\n\x04Like\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12\x33\n\x07\x44islike\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12/\n\x03Pin\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12\x31\n\x05UnPin\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12G\n\x15\x41\x64minDiscussionDelete\x12\x18.social.ToggleDiscussion\x1a\x14.social.common.Empty\x12\x41\n\x15\x41\x64minDiscussionUpdate\x12\x12.social.Discussion\x1a\x14.social.common.Emptyb\x06proto3')



_DISCUSSION = DESCRIPTOR.message_types_by_name['Discussion']
_DISCUSSIONSTAT = DESCRIPTOR.message_types_by_name['DiscussionStat']
_DISCUSSIONLISTRESPONSE = DESCRIPTOR.message_types_by_name['DiscussionListResponse']
_GETDISCUSSIONSREQUEST = DESCRIPTOR.message_types_by_name['GetDiscussionsRequest']
_TOGGLEDISCUSSION = DESCRIPTOR.message_types_by_name['ToggleDiscussion']
Discussion = _reflection.GeneratedProtocolMessageType('Discussion', (_message.Message,), {
  'DESCRIPTOR' : _DISCUSSION,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.Discussion)
  })
_sym_db.RegisterMessage(Discussion)

DiscussionStat = _reflection.GeneratedProtocolMessageType('DiscussionStat', (_message.Message,), {
  'DESCRIPTOR' : _DISCUSSIONSTAT,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.DiscussionStat)
  })
_sym_db.RegisterMessage(DiscussionStat)

DiscussionListResponse = _reflection.GeneratedProtocolMessageType('DiscussionListResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCUSSIONLISTRESPONSE,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.DiscussionListResponse)
  })
_sym_db.RegisterMessage(DiscussionListResponse)

GetDiscussionsRequest = _reflection.GeneratedProtocolMessageType('GetDiscussionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDISCUSSIONSREQUEST,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.GetDiscussionsRequest)
  })
_sym_db.RegisterMessage(GetDiscussionsRequest)

ToggleDiscussion = _reflection.GeneratedProtocolMessageType('ToggleDiscussion', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEDISCUSSION,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.ToggleDiscussion)
  })
_sym_db.RegisterMessage(ToggleDiscussion)

_DISCUSSIONSERVICE = DESCRIPTOR.services_by_name['DiscussionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DISCUSSION._serialized_start=111
  _DISCUSSION._serialized_end=344
  _DISCUSSIONSTAT._serialized_start=346
  _DISCUSSIONSTAT._serialized_end=403
  _DISCUSSIONLISTRESPONSE._serialized_start=405
  _DISCUSSIONLISTRESPONSE._serialized_end=464
  _GETDISCUSSIONSREQUEST._serialized_start=466
  _GETDISCUSSIONSREQUEST._serialized_end=556
  _TOGGLEDISCUSSION._serialized_start=558
  _TOGGLEDISCUSSION._serialized_end=614
  _DISCUSSIONSERVICE._serialized_start=617
  _DISCUSSIONSERVICE._serialized_end=1266
# @@protoc_insertion_point(module_scope)



from mgo_serializer import Serializer


def mongo_to_protobuf(data, fields, schema):
    """
    Convert data to protobuf.
    :return: protobuf
    :rtype: object
    """
    protobuf = schema()
    # Convert QuerySet to protobuf object
    for field, cls in fields.items():
        if data and data[field] is not None:
            if not isinstance(cls, Serializer):
                if cls.proto_field:
                    protobuf.__setattr__(cls.proto_field, data[field])
                else:
                    protobuf.__setattr__(field, data[field])
            else:
                if cls.proto_field:
                    protobuf.MergeFrom(schema(**{cls.proto_field: data[field]}))
                else:
                    protobuf.MergeFrom(schema(**{field: data[field]}))

    return protobuf





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/story/story.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2
from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aservices/story/story.proto\x12\x0csocial.story\x1a\x1eservices/account/account.proto\x1a\x1cservices/common/common.proto\"\xfd\x01\n\x05Story\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32\x17.social.account.Account\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x12\n\nhyper_link\x18\x05 \x01(\t\x12\x14\n\x0cpublished_at\x18\x06 \x01(\x03\x12\x12\n\ndeleted_at\x18\x07 \x01(\x03\x12(\n\nmedia_list\x18\x08 \x03(\x0b\x32\x14.social.common.Media\x12\x0f\n\x07is_seen\x18\t \x01(\x08\x12%\n\x04stat\x18\n \x01(\x0b\x32\x17.social.story.StoryStat\"\x1f\n\tStoryStat\x12\x12\n\nview_count\x18\x01 \x01(\x03\"^\n\x0fGetStoryRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x18\n\x10\x61\x63\x63ount_username\x18\x04 \x01(\t\"H\n\rStoryResponse\x12\"\n\x05story\x18\x01 \x01(\x0b\x32\x13.social.story.Story\x12\x13\n\x0b\x63hecked_all\x18\x02 \x01(\x08\"L\n\x11StoryListResponse\x12\"\n\x05items\x18\x01 \x03(\x0b\x32\x13.social.story.Story\x12\x13\n\x0bis_seen_all\x18\x02 \x01(\x08\"N\n\rStoryFeedItem\x12(\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x17.social.account.Account\x12\x13\n\x0bis_seen_all\x18\x02 \x01(\x08\"4\n\x13GetStoryFeedRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\"?\n\x11StoryFeedResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x1b.social.story.StoryFeedItem\".\n\x0bToggleStory\x12\x10\n\x08story_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x32\xf3\x04\n\x0cStoryService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12Y\n\x10UploadStoryMedia\x12!.social.common.UploadMediaRequest\x1a\".social.common.UploadMediaResponse\x12\x38\n\x0cPublishStory\x12\x13.social.story.Story\x1a\x13.social.story.Story\x12\x38\n\x0b\x44\x65leteStory\x12\x13.social.story.Story\x1a\x14.social.common.Empty\x12\x34\n\x08GetStory\x12\x13.social.story.Story\x1a\x13.social.story.Story\x12L\n\nGetStories\x12\x1d.social.story.GetStoryRequest\x1a\x1f.social.story.StoryListResponse\x12M\n\x07GetFeed\x12!.social.story.GetStoryFeedRequest\x1a\x1f.social.story.StoryFeedResponse\x12I\n\x0bGetArchives\x12\x19.social.common.Pagination\x1a\x1f.social.story.StoryListResponse\x12\x43\n\x10\x41\x64minStoryDelete\x12\x19.social.story.ToggleStory\x1a\x14.social.common.Emptyb\x06proto3')



_STORY = DESCRIPTOR.message_types_by_name['Story']
_STORYSTAT = DESCRIPTOR.message_types_by_name['StoryStat']
_GETSTORYREQUEST = DESCRIPTOR.message_types_by_name['GetStoryRequest']
_STORYRESPONSE = DESCRIPTOR.message_types_by_name['StoryResponse']
_STORYLISTRESPONSE = DESCRIPTOR.message_types_by_name['StoryListResponse']
_STORYFEEDITEM = DESCRIPTOR.message_types_by_name['StoryFeedItem']
_GETSTORYFEEDREQUEST = DESCRIPTOR.message_types_by_name['GetStoryFeedRequest']
_STORYFEEDRESPONSE = DESCRIPTOR.message_types_by_name['StoryFeedResponse']
_TOGGLESTORY = DESCRIPTOR.message_types_by_name['ToggleStory']
Story = _reflection.GeneratedProtocolMessageType('Story', (_message.Message,), {
  'DESCRIPTOR' : _STORY,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.Story)
  })
_sym_db.RegisterMessage(Story)

StoryStat = _reflection.GeneratedProtocolMessageType('StoryStat', (_message.Message,), {
  'DESCRIPTOR' : _STORYSTAT,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryStat)
  })
_sym_db.RegisterMessage(StoryStat)

GetStoryRequest = _reflection.GeneratedProtocolMessageType('GetStoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORYREQUEST,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.GetStoryRequest)
  })
_sym_db.RegisterMessage(GetStoryRequest)

StoryResponse = _reflection.GeneratedProtocolMessageType('StoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORYRESPONSE,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryResponse)
  })
_sym_db.RegisterMessage(StoryResponse)

StoryListResponse = _reflection.GeneratedProtocolMessageType('StoryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORYLISTRESPONSE,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryListResponse)
  })
_sym_db.RegisterMessage(StoryListResponse)

StoryFeedItem = _reflection.GeneratedProtocolMessageType('StoryFeedItem', (_message.Message,), {
  'DESCRIPTOR' : _STORYFEEDITEM,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryFeedItem)
  })
_sym_db.RegisterMessage(StoryFeedItem)

GetStoryFeedRequest = _reflection.GeneratedProtocolMessageType('GetStoryFeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORYFEEDREQUEST,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.GetStoryFeedRequest)
  })
_sym_db.RegisterMessage(GetStoryFeedRequest)

StoryFeedResponse = _reflection.GeneratedProtocolMessageType('StoryFeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORYFEEDRESPONSE,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryFeedResponse)
  })
_sym_db.RegisterMessage(StoryFeedResponse)

ToggleStory = _reflection.GeneratedProtocolMessageType('ToggleStory', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLESTORY,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.ToggleStory)
  })
_sym_db.RegisterMessage(ToggleStory)

_STORYSERVICE = DESCRIPTOR.services_by_name['StoryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORY._serialized_start=107
  _STORY._serialized_end=360
  _STORYSTAT._serialized_start=362
  _STORYSTAT._serialized_end=393
  _GETSTORYREQUEST._serialized_start=395
  _GETSTORYREQUEST._serialized_end=489
  _STORYRESPONSE._serialized_start=491
  _STORYRESPONSE._serialized_end=563
  _STORYLISTRESPONSE._serialized_start=565
  _STORYLISTRESPONSE._serialized_end=641
  _STORYFEEDITEM._serialized_start=643
  _STORYFEEDITEM._serialized_end=721
  _GETSTORYFEEDREQUEST._serialized_start=723
  _GETSTORYFEEDREQUEST._serialized_end=775
  _STORYFEEDRESPONSE._serialized_start=777
  _STORYFEEDRESPONSE._serialized_end=840
  _TOGGLESTORY._serialized_start=842
  _TOGGLESTORY._serialized_end=888
  _STORYSERVICE._serialized_start=891
  _STORYSERVICE._serialized_end=1518
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/stats/stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aservices/stats/stats.proto\x12\x0csocial.stats\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\"!\n\x04Stat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03obj\x18\x02 \x01(\t\"L\n\x10GetActorsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03obj\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\"<\n\x11GetActorsResponse\x12\'\n\x06\x61\x63tors\x18\x01 \x03(\x0b\x32\x17.social.account.Account\"&\n\x11IncrementResponse\x12\x11\n\tis_insert\x18\x01 \x01(\x08\"&\n\x11\x44\x65\x63rementResponse\x12\x11\n\tis_delete\x18\x01 \x01(\x08\x32\xcb\x02\n\x0cStatsService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12@\n\tIncrement\x12\x12.social.stats.Stat\x1a\x1f.social.stats.IncrementResponse\x12@\n\tDecrement\x12\x12.social.stats.Stat\x1a\x1f.social.stats.DecrementResponse\x12\x36\n\x05\x43ount\x12\x12.social.stats.Stat\x1a\x19.social.common.Int64Value\x12L\n\tGetActors\x12\x1e.social.stats.GetActorsRequest\x1a\x1f.social.stats.GetActorsResponseb\x06proto3')



_STAT = DESCRIPTOR.message_types_by_name['Stat']
_GETACTORSREQUEST = DESCRIPTOR.message_types_by_name['GetActorsRequest']
_GETACTORSRESPONSE = DESCRIPTOR.message_types_by_name['GetActorsResponse']
_INCREMENTRESPONSE = DESCRIPTOR.message_types_by_name['IncrementResponse']
_DECREMENTRESPONSE = DESCRIPTOR.message_types_by_name['DecrementResponse']
Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), {
  'DESCRIPTOR' : _STAT,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.Stat)
  })
_sym_db.RegisterMessage(Stat)

GetActorsRequest = _reflection.GeneratedProtocolMessageType('GetActorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORSREQUEST,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.GetActorsRequest)
  })
_sym_db.RegisterMessage(GetActorsRequest)

GetActorsResponse = _reflection.GeneratedProtocolMessageType('GetActorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORSRESPONSE,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.GetActorsResponse)
  })
_sym_db.RegisterMessage(GetActorsResponse)

IncrementResponse = _reflection.GeneratedProtocolMessageType('IncrementResponse', (_message.Message,), {
  'DESCRIPTOR' : _INCREMENTRESPONSE,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.IncrementResponse)
  })
_sym_db.RegisterMessage(IncrementResponse)

DecrementResponse = _reflection.GeneratedProtocolMessageType('DecrementResponse', (_message.Message,), {
  'DESCRIPTOR' : _DECREMENTRESPONSE,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.DecrementResponse)
  })
_sym_db.RegisterMessage(DecrementResponse)

_STATSSERVICE = DESCRIPTOR.services_by_name['StatsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STAT._serialized_start=106
  _STAT._serialized_end=139
  _GETACTORSREQUEST._serialized_start=141
  _GETACTORSREQUEST._serialized_end=217
  _GETACTORSRESPONSE._serialized_start=219
  _GETACTORSRESPONSE._serialized_end=279
  _INCREMENTRESPONSE._serialized_start=281
  _INCREMENTRESPONSE._serialized_end=319
  _DECREMENTRESPONSE._serialized_start=321
  _DECREMENTRESPONSE._serialized_end=359
  _STATSSERVICE._serialized_start=362
  _STATSSERVICE._serialized_end=693
# @@protoc_insertion_point(module_scope)



from collections import OrderedDict

from mgo_serializer.fields import BaseField


class SerializerMetaclass(type):
    """
    This metaclass sets a dictionary named `_declared_fields` on the class.
    Any instances of `Field` included as attributes on either the class
    or on any of its superclasses will be included in the
    `_declared_fields` dictionary.
    """

    @classmethod
    def _get_declared_fields(mcs, bases, attrs):
        fields = [(field_name, attrs.pop(field_name))
                  for field_name, obj in list(attrs.items())
                  if isinstance(obj, BaseField)]
        fields.sort(key=lambda x: x[1]._auto_creation_counter)  # noqa

        # Ensures a base class field doesn't override cls attrs, and maintains
        # field precedence when inheriting multiple parents. e.g. if there is a
        # class C(A, B), and A and B both define 'field', use 'field' from A.
        known = set(attrs)

        def visit(name):
            known.add(name)
            return name

        base_fields = [
            (visit(name), f)
            for base in bases if hasattr(base, '_declared_fields')
            for name, f in base._declared_fields.items() if name not in known # noqa
        ]

        return OrderedDict(base_fields + fields)

    def __new__(mcs, name, bases, attrs):
        attrs['_declared_fields'] = mcs._get_declared_fields(bases, attrs)
        return super().__new__(mcs, name, bases, attrs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/mention/mention.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.post import post_pb2 as services_dot_post_dot_post__pb2
from common.api.services.story import story_pb2 as services_dot_story_dot_story__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/mention/mention.proto\x12\x0esocial.mention\x1a\x1cservices/common/common.proto\x1a\x18services/post/post.proto\x1a\x1aservices/story/story.proto\"d\n\x15GetMentionedInRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x18\n\x10\x61\x63\x63ount_username\x18\x04 \x01(\t2\x81\x02\n\x0eMentionService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12[\n\x13GetMentionedInPosts\x12%.social.mention.GetMentionedInRequest\x1a\x1d.social.post.PostListResponse\x12_\n\x15GetMentionedInStories\x12%.social.mention.GetMentionedInRequest\x1a\x1f.social.story.StoryListResponseb\x06proto3')



_GETMENTIONEDINREQUEST = DESCRIPTOR.message_types_by_name['GetMentionedInRequest']
GetMentionedInRequest = _reflection.GeneratedProtocolMessageType('GetMentionedInRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMENTIONEDINREQUEST,
  '__module__' : 'services.mention.mention_pb2'
  # @@protoc_insertion_point(class_scope:social.mention.GetMentionedInRequest)
  })
_sym_db.RegisterMessage(GetMentionedInRequest)

_MENTIONSERVICE = DESCRIPTOR.services_by_name['MentionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETMENTIONEDINREQUEST._serialized_start=134
  _GETMENTIONEDINREQUEST._serialized_end=234
  _MENTIONSERVICE._serialized_start=237
  _MENTIONSERVICE._serialized_end=494
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/common/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cservices/common/common.proto\x12\rsocial.common\"\x12\n\x04Pong\x12\n\n\x02ts\x18\x01 \x01(\x03\";\n\x0b\x46indRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"\x07\n\x05\x45mpty\"\xcc\x01\n\x05Media\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\x10\n\x08\x64uration\x18\x05 \x01(\x05\x12\x31\n\x0cmention_list\x18\x06 \x03(\x0b\x32\x1b.social.common.MediaMention\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x12\x11\n\tthumbnail\x18\x08 \x01(\t\x12\x11\n\tthumb_url\x18\t \x01(\t\x12\x0c\n\x04link\x18\n \x01(\t\"6\n\x0cMediaMention\x12\x10\n\x08username\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\")\n\x13UploadMediaResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\"4\n\x12UploadMediaRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"+\n\nPagination\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\"\x1d\n\x0c\x42ooleanValue\x12\r\n\x05value\x18\x01 \x01(\x08\"\x1b\n\nInt64Value\x12\r\n\x05value\x18\x01 \x01(\x03\"%\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"9\n\x0f\x43\x61tListResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.common.Category\"3\n\x08Location\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0c\n\x04long\x18\x03 \x01(\x01\"Q\n\rPublishStatus\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32 .social.common.PublishStatusEnum\x12\x0e\n\x06reason\x18\x02 \x01(\t\"D\n\x14PublishStatusRequest\x12,\n\x06status\x18\x01 \x01(\x0b\x32\x1c.social.common.PublishStatus\"0\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05*<\n\x11PublishStatusEnum\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41PPROVED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x62\x06proto3')

_PUBLISHSTATUSENUM = DESCRIPTOR.enum_types_by_name['PublishStatusEnum']
PublishStatusEnum = enum_type_wrapper.EnumTypeWrapper(_PUBLISHSTATUSENUM)
PENDING = 0
APPROVED = 1
REJECTED = 2


_PONG = DESCRIPTOR.message_types_by_name['Pong']
_FINDREQUEST = DESCRIPTOR.message_types_by_name['FindRequest']
_EMPTY = DESCRIPTOR.message_types_by_name['Empty']
_MEDIA = DESCRIPTOR.message_types_by_name['Media']
_MEDIAMENTION = DESCRIPTOR.message_types_by_name['MediaMention']
_UPLOADMEDIARESPONSE = DESCRIPTOR.message_types_by_name['UploadMediaResponse']
_UPLOADMEDIAREQUEST = DESCRIPTOR.message_types_by_name['UploadMediaRequest']
_PAGINATION = DESCRIPTOR.message_types_by_name['Pagination']
_BOOLEANVALUE = DESCRIPTOR.message_types_by_name['BooleanValue']
_INT64VALUE = DESCRIPTOR.message_types_by_name['Int64Value']
_CATEGORY = DESCRIPTOR.message_types_by_name['Category']
_CATLISTRESPONSE = DESCRIPTOR.message_types_by_name['CatListResponse']
_LOCATION = DESCRIPTOR.message_types_by_name['Location']
_PUBLISHSTATUS = DESCRIPTOR.message_types_by_name['PublishStatus']
_PUBLISHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['PublishStatusRequest']
_DATE = DESCRIPTOR.message_types_by_name['Date']
Pong = _reflection.GeneratedProtocolMessageType('Pong', (_message.Message,), {
  'DESCRIPTOR' : _PONG,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Pong)
  })
_sym_db.RegisterMessage(Pong)

FindRequest = _reflection.GeneratedProtocolMessageType('FindRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDREQUEST,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.FindRequest)
  })
_sym_db.RegisterMessage(FindRequest)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Empty)
  })
_sym_db.RegisterMessage(Empty)

Media = _reflection.GeneratedProtocolMessageType('Media', (_message.Message,), {
  'DESCRIPTOR' : _MEDIA,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Media)
  })
_sym_db.RegisterMessage(Media)

MediaMention = _reflection.GeneratedProtocolMessageType('MediaMention', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAMENTION,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.MediaMention)
  })
_sym_db.RegisterMessage(MediaMention)

UploadMediaResponse = _reflection.GeneratedProtocolMessageType('UploadMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADMEDIARESPONSE,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.UploadMediaResponse)
  })
_sym_db.RegisterMessage(UploadMediaResponse)

UploadMediaRequest = _reflection.GeneratedProtocolMessageType('UploadMediaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADMEDIAREQUEST,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.UploadMediaRequest)
  })
_sym_db.RegisterMessage(UploadMediaRequest)

Pagination = _reflection.GeneratedProtocolMessageType('Pagination', (_message.Message,), {
  'DESCRIPTOR' : _PAGINATION,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Pagination)
  })
_sym_db.RegisterMessage(Pagination)

BooleanValue = _reflection.GeneratedProtocolMessageType('BooleanValue', (_message.Message,), {
  'DESCRIPTOR' : _BOOLEANVALUE,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.BooleanValue)
  })
_sym_db.RegisterMessage(BooleanValue)

Int64Value = _reflection.GeneratedProtocolMessageType('Int64Value', (_message.Message,), {
  'DESCRIPTOR' : _INT64VALUE,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Int64Value)
  })
_sym_db.RegisterMessage(Int64Value)

Category = _reflection.GeneratedProtocolMessageType('Category', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORY,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Category)
  })
_sym_db.RegisterMessage(Category)

CatListResponse = _reflection.GeneratedProtocolMessageType('CatListResponse', (_message.Message,), {
  'DESCRIPTOR' : _CATLISTRESPONSE,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.CatListResponse)
  })
_sym_db.RegisterMessage(CatListResponse)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Location)
  })
_sym_db.RegisterMessage(Location)

PublishStatus = _reflection.GeneratedProtocolMessageType('PublishStatus', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHSTATUS,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.PublishStatus)
  })
_sym_db.RegisterMessage(PublishStatus)

PublishStatusRequest = _reflection.GeneratedProtocolMessageType('PublishStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHSTATUSREQUEST,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.PublishStatusRequest)
  })
_sym_db.RegisterMessage(PublishStatusRequest)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
  'DESCRIPTOR' : _DATE,
  '__module__' : 'services.common.common_pb2'
  # @@protoc_insertion_point(class_scope:social.common.Date)
  })
_sym_db.RegisterMessage(Date)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLISHSTATUSENUM._serialized_start=956
  _PUBLISHSTATUSENUM._serialized_end=1016
  _PONG._serialized_start=47
  _PONG._serialized_end=65
  _FINDREQUEST._serialized_start=67
  _FINDREQUEST._serialized_end=126
  _EMPTY._serialized_start=128
  _EMPTY._serialized_end=135
  _MEDIA._serialized_start=138
  _MEDIA._serialized_end=342
  _MEDIAMENTION._serialized_start=344
  _MEDIAMENTION._serialized_end=398
  _UPLOADMEDIARESPONSE._serialized_start=400
  _UPLOADMEDIARESPONSE._serialized_end=441
  _UPLOADMEDIAREQUEST._serialized_start=443
  _UPLOADMEDIAREQUEST._serialized_end=495
  _PAGINATION._serialized_start=497
  _PAGINATION._serialized_end=540
  _BOOLEANVALUE._serialized_start=542
  _BOOLEANVALUE._serialized_end=571
  _INT64VALUE._serialized_start=573
  _INT64VALUE._serialized_end=600
  _CATEGORY._serialized_start=602
  _CATEGORY._serialized_end=639
  _CATLISTRESPONSE._serialized_start=641
  _CATLISTRESPONSE._serialized_end=698
  _LOCATION._serialized_start=700
  _LOCATION._serialized_end=751
  _PUBLISHSTATUS._serialized_start=753
  _PUBLISHSTATUS._serialized_end=834
  _PUBLISHSTATUSREQUEST._serialized_start=836
  _PUBLISHSTATUSREQUEST._serialized_end=904
  _DATE._serialized_start=906
  _DATE._serialized_end=954
# @@protoc_insertion_point(module_scope)
